#include "stm32f4xx.h"
#include "systick.h"
#include "discovery-hardware.h"

/* Private typedef -----------------------------------------------------------*/
GPIO_InitTypeDef GPIO_InitStructure;
RCC_ClocksTypeDef RCC_Clocks;

uint32_t delayTime;

void hardwareInit(void) {
  /*  Everything need a clock */
  RCC_AHB1PeriphClockCmd(GREEN_LED_PORT_CLOCK, ENABLE);
  RCC_AHB1PeriphClockCmd(ORANGE_LED_PORT_CLOCK, ENABLE);
  RCC_AHB1PeriphClockCmd(RED_LED_PORT_CLOCK, ENABLE);
  RCC_AHB1PeriphClockCmd(BLUE_LED_PORT_CLOCK, ENABLE);
  /*
   * Configure the LED pins as low speed push-pull outputs
   * First set the common properties
   */
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_InitStructure.GPIO_Pin = GREEN_LED_PIN;
  GPIO_Init(GREEN_LED_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = ORANGE_LED_PIN;
  GPIO_Init(ORANGE_LED_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = RED_LED_PIN;
  GPIO_Init(RED_LED_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = BLUE_LED_PIN;
  GPIO_Init(BLUE_LED_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = TEST_PIN_PIN;
  GPIO_Init(TEST_PIN_PORT, &GPIO_InitStructure);

  MAX6966_init();
}

int main(void) {
  int ledNumber;
  uint8_t brightness;
  /*
   * At this stage the microcontroller clock setting is already configured,
   * this is done through SystemInit() function which is called from startup
   * file (startup_stm32f4xx.s) before the branch to application main().
   * To reconfigure the default setting of SystemInit() function, refer to
   * system_stm32f4xx.c file
   */
  hardwareInit();
  /*
   * set up SysTick to generate an event each millisecond
   */
  RCC_GetClocksFreq(&RCC_Clocks);
  SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000);

  /*
   * SPI polled writes control a MAX6966 10 led pwm driver
   */
  brightness = 0;
  ledNumber = 0;
  delayTime = 15;
  while (1) {
    setLED(ledNumber, 0);
    ledNumber++;
    if (ledNumber > 9) {
      ledNumber = 0;
      brightness += 26;
    }
    setLED(ledNumber, brightness);
    delay_ms(delayTime);
  }
}

#ifdef  USE_FULL_ASSERT

/**
 * @brief  Reports the name of the source file and the source line number
 *         where the assert_param error has occurred.
 * @param  file: pointer to the source file name
 * @param  line: assert_param error line source number
 * @retval None
 */
void assert_failed(uint8_t* file, uint32_t line) {
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1) {
  }
}
#endif

